@@ -1,4 +1,6 @@
 """Submodel for franchise_tree.py"""
+from typing import Optional
+
 from pydantic import BaseModel
 
 
@@ -9,6 +11,6 @@ class TreeNode(BaseModel):
     name: str
     image_url: str
     url: str
-    year: int
+    year: Optional[int]
     kind: str
     weight: int
